/********************************************************/
/*  psxscl: a thread-safe system call layer library     */
/*  Copyright (C) 2013--2021  SysDeer Technologies, LLC */
/*  Released under GPLv2 and GPLv3; see COPYING.PSXSCL. */
/********************************************************/

#ifndef _SYS_SYSAPI_H_
#define _SYS_SYSAPI_H_

#ifndef  __psx_api
#define  __psx_api
#endif

#include "sys_abitypes.h"
#include "sys_dirent.h"
#include "sys_ofd.h"
#include "sys_pollen.h"
#include "sys_profile.h"
#include "sys_ptrace.h"
#include "sys_strace.h"
#include "sys_resource.h"
#include "sys_sched.h"
#include "sys_sigfn.h"
#include "sys_msg.h"
#include "sys_sem.h"
#include "sys_shm.h"
#include "sys_socket.h"
#include "sys_stat.h"
#include "sys_debug.h"
#include "sys_sysinfo.h"
#include "sys_syscalls.h"

#define __sys_routine(routine) \
	__sys_routine__##routine

#define __sys_interface(routine) \
	__psx_api __sys_routine(routine) __sys_##routine

/* brk */
typedef intptr_t	__sys_routine(brk)(uintptr_t brk);
typedef intptr_t	__sys_routine(madvise)(void * addr, size_t length, int advice);

/* fcntl */
typedef intptr_t	__sys_routine(dup)(int);
typedef intptr_t	__sys_routine(dup2)(int, int);
typedef intptr_t	__sys_routine(dup3)(int, int, int flags);
typedef intptr_t	__sys_routine(fcntl)(int, int cmd, void * arg);

/* fd,ofd */
typedef intptr_t	__sys_routine(close)(int);
typedef intptr_t	__sys_routine(creat)(const unsigned char *, mode_t);
typedef intptr_t	__sys_routine(open)(const unsigned char *, int, mode_t);
typedef intptr_t	__sys_routine(openat)(int, const unsigned char *, int, mode_t);

/* fs */
typedef intptr_t	__sys_routine(access)(const unsigned char * path, int amode);
typedef intptr_t	__sys_routine(faccessat)(int, const unsigned char * path, int amode, int flag);
typedef intptr_t	__sys_routine(chdir)(const unsigned char *);
typedef intptr_t	__sys_routine(fchdir)(int);
typedef intptr_t	__sys_routine(chmod)(const unsigned char * path, mode_t mode);
typedef intptr_t	__sys_routine(fchmod)(int, mode_t mode);
typedef intptr_t	__sys_routine(fchmodat)(int, const unsigned char * path, mode_t mode, int flag);
typedef intptr_t	__sys_routine(chown)(const unsigned char * path, uid_t owner, gid_t group);
typedef intptr_t	__sys_routine(fchown)(int fdidx, uid_t owner, gid_t group);
typedef intptr_t	__sys_routine(lchown)(const unsigned char * path, uid_t owner, gid_t group);
typedef intptr_t	__sys_routine(getcwd)(char * buf, size_t size);
typedef intptr_t	__sys_routine(getdents)(int, struct __dirent *, size_t);
typedef intptr_t	__sys_routine(fstat)(int, struct __stat * xstat);
typedef intptr_t	__sys_routine(fstatat)(int, const unsigned char * path, struct __stat * xstat, int flag);
typedef intptr_t	__sys_routine(lstat)(const unsigned char * path, struct __stat * xstat);
typedef intptr_t	__sys_routine(stat)(const unsigned char * path, struct __stat * xstat);
typedef intptr_t	__sys_routine(link)(const unsigned char * src, const unsigned char * dst);
typedef intptr_t	__sys_routine(linkat)(int, const unsigned char * src, int, const unsigned char * dst, int flag);
typedef intptr_t	__sys_routine(symlink)(const char * target, const unsigned char * path);
typedef intptr_t	__sys_routine(symlinkat)(const char * target, int fd, const unsigned char * path);
typedef intptr_t	__sys_routine(mkdir)(const unsigned char * path, mode_t mode);
typedef intptr_t	__sys_routine(mkdirat)(int, const unsigned char * path, mode_t mode);
typedef ssize_t		__sys_routine(readlink)(const unsigned char * path, char * buf, size_t);
typedef ssize_t		__sys_routine(readlinkat)(int, const unsigned char * path, char * buf, size_t);
typedef intptr_t	__sys_routine(rename)(const unsigned char * src, const unsigned char * dst);
typedef intptr_t	__sys_routine(renameat)(int, const unsigned char * src, int, const unsigned char * dst);
typedef intptr_t	__sys_routine(rmdir)(const unsigned char * path);
typedef intptr_t	__sys_routine(truncate)(const unsigned char * path, off_t length);
typedef intptr_t	__sys_routine(ftruncate)(int, off_t length);
typedef intptr_t	__sys_routine(unlink)(const unsigned char *path);
typedef intptr_t	__sys_routine(unlinkat)(int, const unsigned char * path, int flag);
typedef intptr_t	__sys_routine(utimensat)(int, const unsigned char * path, const struct timespec[2], int flag);
typedef intptr_t	__sys_routine(fs_rpath)(int, const char *, int, char *, size_t);
typedef intptr_t	__sys_routine(fs_apath)(int, const char *, int, char *, size_t);
typedef intptr_t	__sys_routine(fs_npath)(int, const char *, int, char *, size_t);
typedef intptr_t	__sys_routine(fs_dpath)(int, const char *, int, char *, size_t);
typedef intptr_t	__sys_routine(fs_mkdir)(int, const unsigned char * path, mode_t mode, uint32_t ace_flags);
typedef intptr_t	__sys_routine(fs_chmod)(int, const unsigned char * path, mode_t mode, int flag, uint32_t ace_flags);
typedef intptr_t	__sys_routine(fs_tmpfile)(int);
typedef intptr_t	__sys_routine(fs_tmpdir)(int);

/* ioctl */
typedef intptr_t	__sys_routine(ioctl)(int, unsigned long, void *);

/* ipc */
typedef intptr_t	__sys_routine(pipe)(int[2]);
typedef intptr_t	__sys_routine(pipe2)(int[2],int flags);

/* kernel */
typedef intptr_t	__sys_routine(clock_getres)(clockid_t clock_id, struct timespec * res);
typedef intptr_t	__sys_routine(clock_gettime)(clockid_t clock_id, struct timespec * tp);
typedef intptr_t	__sys_routine(clock_settime)(clockid_t clock_id, const struct timespec * tp);
typedef intptr_t	__sys_routine(getrandom)(void *, size_t, unsigned int);
typedef intptr_t	__sys_routine(gettimeofday)(struct timeval * tp, void * tzp);
typedef intptr_t	__sys_routine(sysinfo)(struct __sysinfo * info);
typedef intptr_t	__sys_routine(uname)(struct __utsname *);

/* mman */
typedef void *		__sys_routine(mmap)(void * addr, size_t length, int prot, int flags, int,off_t offset);
typedef intptr_t	__sys_routine(mprotect)(void * addr, size_t length, int prot);
typedef void *		__sys_routine(mremap)(void * mapaddr, size_t mapsize, size_t newsize, int flags);
typedef intptr_t	__sys_routine(munmap)(void * addr, size_t length);

/* mount */
typedef intptr_t	__sys_routine(mount)(const char * source, const char * target, const char * fstype, uintptr_t mntflags, const void * data);

/* msg */
typedef intptr_t	__sys_routine(msgctl)(key_t msqid, int cmd, struct __msqid_ds * msqds);
typedef intptr_t	__sys_routine(msgget)(key_t, int msqflg);
typedef intptr_t	__sys_routine(msgrcv)(key_t, void * packet, size_t size, intptr_t rank, int flag);
typedef intptr_t	__sys_routine(msgsnd)(key_t, const void * packet, size_t size, int flag);

 /* process */
typedef intptr_t	__sys_routine(execve)(const unsigned char * path, const char ** argv, const char ** envp);
typedef intptr_t	__sys_routine(strace)(const unsigned char * path, const char ** argv, const char ** envp, const struct __strace *);
typedef void		__sys_routine(exit)(int);
typedef void		__sys_routine(exit_group)(int);
typedef intptr_t	__sys_routine(fork)(void);
typedef intptr_t	__sys_routine(vfork)(void);

/* profile */
typedef clock_t		__sys_routine(times)(struct tms * buf);

/* resource */
typedef intptr_t	__sys_routine(getrlimit)(int resource, struct __rlimit * rlim);
typedef intptr_t	__sys_routine(getrusage)(int who, struct __rusage * r_usage);
typedef intptr_t	__sys_routine(prlimit)(pid_t pid, int resource, const struct __rlimit * new_limit, struct __rlimit * old_limit);
typedef intptr_t	__sys_routine(setrlimit)(int resource, const struct __rlimit * rlim);

/* scheduler */
typedef intptr_t 	__sys_routine(sched_get_priority_min)(int policy);
typedef intptr_t 	__sys_routine(sched_get_priority_max)(int policy);
typedef intptr_t 	__sys_routine(sched_getaffinity)(pid_t pid, size_t cpusetsize, struct __cpu_set_t * mask);
typedef intptr_t 	__sys_routine(sched_setaffinity)(pid_t pid, size_t cpusetsize, const struct __cpu_set_t * mask);
typedef intptr_t 	__sys_routine(sched_getattr)(pid_t pid, struct sched_attr *, unsigned int size, unsigned int flags);
typedef intptr_t 	__sys_routine(sched_setattr)(pid_t pid, struct sched_attr *, unsigned int flags);
typedef intptr_t 	__sys_routine(sched_getparam)(pid_t pid, struct sched_param *);
typedef intptr_t 	__sys_routine(sched_setparam)(pid_t pid, const struct sched_param *);
typedef intptr_t 	__sys_routine(sched_getscheduler)(pid_t pid);
typedef intptr_t 	__sys_routine(sched_setscheduler)(pid_t pid, int policy, const struct sched_param *);
typedef intptr_t 	__sys_routine(sched_rr_get_interval)(pid_t pid, struct timespec * tp);
typedef intptr_t 	__sys_routine(sched_yield)(void);

/* sem */
typedef intptr_t	__sys_routine(semctl)(key_t, int semnum, int cmd, void *);
typedef intptr_t	__sys_routine(semget)(key_t, int nsems, int semflg);
typedef intptr_t	__sys_routine(semop)(key_t, struct __semop *, size_t nsops);

/* session */
typedef intptr_t	__sys_routine(chroot)(const unsigned char *);
typedef intptr_t	__sys_routine(getpid)(void);
typedef intptr_t	__sys_routine(getppid)(void);
typedef intptr_t	__sys_routine(getpgid)(pid_t);
typedef intptr_t	__sys_routine(getpgrp)(pid_t pid);
typedef intptr_t	__sys_routine(setpgid)(pid_t pid, pid_t pgid);
typedef intptr_t	__sys_routine(getsid)(pid_t);
typedef intptr_t	__sys_routine(setsid)(void);
typedef intptr_t	__sys_routine(wait4)(pid_t, int * status, int options, struct __rusage *);
typedef intptr_t	__sys_routine(waitid)(int idtype, id_t id, siginfo_t *, int options);

/* shm */
typedef void *		__sys_routine(shmat)(int shmid, const void * shmaddr, int shmflg);
typedef intptr_t	__sys_routine(shmctl)(int shmid, int cmd, struct __shmid_ds * buf);
typedef intptr_t	__sys_routine(shmget)(key_t key, size_t size, int shmflg);

/* signal */
typedef intptr_t	__sys_routine(rt_sigaction)(int signum, const struct __sigaction * act, struct __sigaction * oldact, size_t sigsetsize);
typedef intptr_t	__sys_routine(rt_sigprocmask)(int,const sigset_t *,sigset_t *, size_t);
typedef intptr_t	__sys_routine(rt_sigsuspend)(const sigset_t *);
typedef intptr_t	__sys_routine(getitimer)(int32_t which, struct itimerval * curr_value);
typedef intptr_t	__sys_routine(setitimer)(int32_t which, const struct itimerval * new_value, struct itimerval * old_value);
typedef intptr_t	__sys_routine(kill)(pid_t, int);
typedef intptr_t	__sys_routine(tkill)(pid_t, int);
typedef intptr_t	__sys_routine(tgkill)(pid_t, pid_t, int);
typedef intptr_t	__sys_routine(nanosleep)(const struct timespec *, struct timespec *);
typedef intptr_t	__sys_routine(clock_nanosleep)(clockid_t clock_id,int,const struct timespec *,struct timespec *	rem);

/* socket */
typedef intptr_t	__sys_routine(accept)(int, struct __sockaddr *, socklen_t *);
typedef intptr_t	__sys_routine(bind)(int, const struct __sockaddr *, socklen_t);
typedef intptr_t	__sys_routine(connect)(int, const struct __sockaddr *, socklen_t);
typedef intptr_t	__sys_routine(getpeername)(int, struct __sockaddr *, socklen_t *);
typedef intptr_t	__sys_routine(getsockname)(int, struct __sockaddr *, socklen_t *);
typedef intptr_t	__sys_routine(getsockopt)(int, int, int, void *, socklen_t *);
typedef intptr_t	__sys_routine(listen)(int, int);
typedef ssize_t		__sys_routine(recvfrom)(int, void *, size_t, int, struct __sockaddr *, socklen_t *);
typedef ssize_t		__sys_routine(recvmsg)(int, struct __msghdr *, int);
typedef ssize_t		__sys_routine(sendmsg)(int, const struct __msghdr *, int);
typedef ssize_t		__sys_routine(sendto)(int, const void *, size_t, int, const struct __sockaddr *, socklen_t);
typedef intptr_t	__sys_routine(setsockopt)(int, int, int, const void *, socklen_t);
typedef intptr_t	__sys_routine(shutdown)(int, int);
typedef intptr_t	__sys_routine(socket)(int, int, int);
typedef intptr_t	__sys_routine(socketpair)(int, int, int, int[2]);

/* stdio */
typedef intptr_t	__sys_routine(flock)(int, int);
typedef intptr_t	__sys_routine(fsync)(int);
typedef intptr_t	__sys_routine(fdatasync)(int);
typedef off_t		__sys_routine(lseek)(int,off_t,int);
typedef ssize_t		__sys_routine(pread)(int,void *,size_t,off_t);
typedef ssize_t		__sys_routine(pwrite)(int,const void *,size_t,off_t);
typedef ssize_t		__sys_routine(read)(int,void *,size_t);
typedef ssize_t		__sys_routine(readv)(int,const struct iovec *,int);
typedef ssize_t		__sys_routine(write)(int,const void *,size_t);
typedef ssize_t		__sys_routine(writev)(int,const struct iovec *,int);
typedef ssize_t		__sys_routine(splice)(int fd_in, off_t * off_in, int fd_out, off_t * off_out, size_t len, uint32_t flags);

/* telegraphy */
typedef intptr_t	__sys_routine(poll)(struct __pollfd fds[], uintptr_t nfds, int timeout);
typedef intptr_t	__sys_routine(ppoll)(struct __pollfd fds[], uintptr_t nfds, const struct timespec *, const sigset_t *);
typedef intptr_t	__sys_routine(select)(int nfds, struct __fd_set *, struct __fd_set *, struct __fd_set *, struct timeval *);
typedef intptr_t	__sys_routine(pselect)(int nfds, struct __fd_set *, struct __fd_set *, struct __fd_set *, const struct timespec *, const sigset_t * const *);

/* thread */
typedef intptr_t	__sys_routine(clone)(uintptr_t flags, void * child_stack, void * ptid, void * ctid, struct pt_regs * regs);
typedef intptr_t	__sys_routine(futex)(int *,int,int,const struct timespec *,int *,int);
typedef intptr_t	__sys_routine(gettid)(void);
typedef intptr_t	__sys_routine(set_tid_address)(int *);

/* token */
typedef gid_t		__sys_routine(getegid)(void);
typedef uid_t		__sys_routine(geteuid)(void);
typedef gid_t		__sys_routine(getgid)(void);
typedef uid_t		__sys_routine(getuid)(void);
typedef intptr_t	__sys_routine(setgid)(gid_t);
typedef intptr_t	__sys_routine(setuid)(uid_t);
typedef intptr_t	__sys_routine(setreuid)(uid_t,uid_t);
typedef intptr_t	__sys_routine(setregid)(gid_t,gid_t);
typedef intptr_t	__sys_routine(getresuid)(uid_t *,uid_t *,uid_t *);
typedef intptr_t	__sys_routine(getresgid)(gid_t *,gid_t *,gid_t *);
typedef intptr_t	__sys_routine(setresuid)(uid_t,uid_t,uid_t);
typedef intptr_t	__sys_routine(setresgid)(gid_t,gid_t,gid_t);
typedef intptr_t	__sys_routine(umask)(mode_t);

/* dbg */
typedef intptr_t	__sys_routine(dbg_attach)(pid_t);
typedef intptr_t	__sys_routine(dbg_detach)(int);
typedef intptr_t	__sys_routine(dbg_spawn)(const unsigned char * path, const char ** argv, const char ** envp, const struct __strace *);
typedef intptr_t	__sys_routine(dbg_fork)(void);
typedef intptr_t	__sys_routine(dbg_kill)(int);
typedef intptr_t	__sys_routine(dbg_rbreak)(int);
typedef intptr_t	__sys_routine(dbg_tbreak)(int);
typedef intptr_t	__sys_routine(dbg_lbreak)(int);
typedef intptr_t	__sys_routine(dbg_vm_read)(int, void *, size_t, uintptr_t);
typedef intptr_t	__sys_routine(dbg_vm_write)(int, const void *, size_t, uintptr_t);
typedef intptr_t	__sys_routine(dbg_regs_fetch)(int, pid_t, mcontext_t *);
typedef intptr_t	__sys_routine(dbg_regs_store)(int, pid_t, const mcontext_t *);
typedef intptr_t	__sys_routine(dbg_info_get)(int, pid_t, int, void *, size_t);
typedef intptr_t	__sys_routine(dbg_info_set)(int, pid_t, int, const void *, size_t);
typedef intptr_t	__sys_routine(dbg_suspend_thread)(int, pid_t);
typedef intptr_t	__sys_routine(dbg_resume_thread)(int, pid_t);
typedef intptr_t	__sys_routine(dbg_event_query_one)(int, struct __dbg_event *);
typedef intptr_t	__sys_routine(dbg_event_query_all)(int, struct __dbg_event *, int);
typedef intptr_t	__sys_routine(dbg_event_acquire)(int, struct __dbg_event *);
typedef intptr_t	__sys_routine(dbg_event_respond)(int, struct __dbg_event *);
typedef intptr_t	__sys_routine(dbg_query_cpid)(int);
typedef intptr_t	__sys_routine(dbg_query_syspid)(int);
typedef intptr_t	__sys_routine(dbg_common_error)(void);
typedef intptr_t	__sys_routine(dbg_native_error)(void);

/* cmd */
typedef intptr_t	__sys_routine(cmd_args_to_argv)(const char *, char *, size_t, char **, size_t);

/* brk */
__sys_interface(brk);
__sys_interface(madvise);

/* fcntl */
__sys_interface(dup);
__sys_interface(dup2);
__sys_interface(dup3);
__sys_interface(fcntl);

/* fd,ofd */
__sys_interface(close);
__sys_interface(creat);
__sys_interface(open);
__sys_interface(openat);

/* fs */
__sys_interface(access);
__sys_interface(faccessat);
__sys_interface(chdir);
__sys_interface(fchdir);
__sys_interface(chmod);
__sys_interface(fchmod);
__sys_interface(fchmodat);
__sys_interface(chown);
__sys_interface(fchown);
__sys_interface(lchown);
__sys_interface(getcwd);
__sys_interface(getdents);
__sys_interface(fstat);
__sys_interface(fstatat);
__sys_interface(lstat);
__sys_interface(stat);
__sys_interface(link);
__sys_interface(linkat);
__sys_interface(symlink);
__sys_interface(symlinkat);
__sys_interface(mkdir);
__sys_interface(mkdirat);
__sys_interface(readlink);
__sys_interface(readlinkat);
__sys_interface(rename);
__sys_interface(renameat);
__sys_interface(rmdir);
__sys_interface(truncate);
__sys_interface(ftruncate);
__sys_interface(unlink);
__sys_interface(unlinkat);
__sys_interface(utimensat);
__sys_interface(fs_rpath);
__sys_interface(fs_apath);
__sys_interface(fs_npath);
__sys_interface(fs_dpath);
__sys_interface(fs_mkdir);
__sys_interface(fs_chmod);
__sys_interface(fs_tmpfile);
__sys_interface(fs_tmpdir);

/* ioctl */
__sys_interface(ioctl);

/* ipc */
__sys_interface(pipe);
__sys_interface(pipe2);

/* kernel */
__sys_interface(clock_getres);
__sys_interface(clock_gettime);
__sys_interface(clock_settime);
__sys_interface(getrandom);
__sys_interface(gettimeofday);
__sys_interface(sysinfo);
__sys_interface(uname);

/* mman */
__sys_interface(mmap);
__sys_interface(mprotect);
__sys_interface(mremap);
__sys_interface(munmap);

/* mount */
__sys_interface(mount);

/* msg */
__sys_interface(msgctl);
__sys_interface(msgget);
__sys_interface(msgrcv);
__sys_interface(msgsnd);

 /* process */
__sys_interface(execve);
__sys_interface(strace);
__sys_interface(exit);
__sys_interface(exit_group);
__sys_interface(fork);
__sys_interface(vfork);

/* profile */
__sys_interface(times);

/* resource */
__sys_interface(getrlimit);
__sys_interface(getrusage);
__sys_interface(prlimit);
__sys_interface(setrlimit);

/* scheduler */
__sys_interface(sched_get_priority_min);
__sys_interface(sched_get_priority_max);
__sys_interface(sched_getaffinity);
__sys_interface(sched_setaffinity);
__sys_interface(sched_getattr);
__sys_interface(sched_setattr);
__sys_interface(sched_getparam);
__sys_interface(sched_setparam);
__sys_interface(sched_getscheduler);
__sys_interface(sched_setscheduler);
__sys_interface(sched_rr_get_interval);
__sys_interface(sched_yield);

/* sem */
__sys_interface(semctl);
__sys_interface(semget);
__sys_interface(semop);

/* session */
__sys_interface(chroot);
__sys_interface(getpid);
__sys_interface(getppid);
__sys_interface(getpgid);
__sys_interface(getpgrp);
__sys_interface(setpgid);
__sys_interface(getsid);
__sys_interface(setsid);
__sys_interface(wait4);
__sys_interface(waitid);

/* shm */
__sys_interface(shmat);
__sys_interface(shmctl);
__sys_interface(shmget);

/* signal */
__sys_interface(rt_sigaction);
__sys_interface(rt_sigprocmask);
__sys_interface(rt_sigsuspend);
__sys_interface(getitimer);
__sys_interface(setitimer);
__sys_interface(kill);
__sys_interface(tkill);
__sys_interface(tgkill);
__sys_interface(nanosleep);
__sys_interface(clock_nanosleep);

/* socket */
__sys_interface(accept);
__sys_interface(bind);
__sys_interface(connect);
__sys_interface(getpeername);
__sys_interface(getsockname);
__sys_interface(getsockopt);
__sys_interface(listen);
__sys_interface(recvfrom);
__sys_interface(recvmsg);
__sys_interface(sendmsg);
__sys_interface(sendto);
__sys_interface(setsockopt);
__sys_interface(shutdown);
__sys_interface(socket);
__sys_interface(socketpair);

/* stdio */
__sys_interface(flock);
__sys_interface(fsync);
__sys_interface(fdatasync);
__sys_interface(lseek);
__sys_interface(pread);
__sys_interface(pwrite);
__sys_interface(read);
__sys_interface(readv);
__sys_interface(write);
__sys_interface(writev);
__sys_interface(splice);

/* telegraphy */
__sys_interface(poll);
__sys_interface(ppoll);
__sys_interface(select);
__sys_interface(pselect);

/* thread */
__sys_interface(clone);
__sys_interface(futex);
__sys_interface(gettid);
__sys_interface(set_tid_address);

/* token */
__sys_interface(getegid);
__sys_interface(geteuid);
__sys_interface(getgid);
__sys_interface(getuid);
__sys_interface(setgid);
__sys_interface(setuid);
__sys_interface(setreuid);
__sys_interface(setregid);
__sys_interface(getresuid);
__sys_interface(getresgid);
__sys_interface(setresuid);
__sys_interface(setresgid);
__sys_interface(umask);

/* dbg */
__sys_interface(dbg_attach);
__sys_interface(dbg_detach);
__sys_interface(dbg_spawn);
__sys_interface(dbg_kill);
__sys_interface(dbg_rbreak);
__sys_interface(dbg_tbreak);
__sys_interface(dbg_lbreak);
__sys_interface(dbg_vm_read);
__sys_interface(dbg_vm_write);
__sys_interface(dbg_regs_fetch);
__sys_interface(dbg_regs_store);
__sys_interface(dbg_info_get);
__sys_interface(dbg_info_set);
__sys_interface(dbg_suspend_thread);
__sys_interface(dbg_resume_thread);
__sys_interface(dbg_event_acquire);
__sys_interface(dbg_event_respond);
__sys_interface(dbg_query_cpid);
__sys_interface(dbg_query_syspid);

/* cmd */
__sys_interface(cmd_args_to_argv);

#endif
